@@ -10,34 +10,30 @@ function(metric, modelx, modely, datax, datay=datax, addCostsx=NULL, addCostsy=N
         stop("Need data to plot performances!")
     }
 
-    idCols = intersect(datax$ids, datay$ids)
+    idCols = intersect(c(datax$ids, datax$extra), c(datay$ids, datay$extra))
     if(length(idCols) == 0) {
         stop("Cannot match up the two data frames!")
     }
 
     if(length(datax$test) > 0) {
-        edatax = do.call(rbind, lapply(datax$test, function(x) {
+        edatax = rbind.fill(lapply(datax$test, function(x) {
             datax$data[x,idCols,drop=F]
         }))
     } else {
-        if(!is.null(datax$extra)) {
-            sel = c(idCols, datax$extra)
-        } else {
-            sel = idCols
-        }
-        edatax = datax$data[sel]
+        edatax = datax$data[idCols]
+    }
+    if(!is.null(datax$extra)) {
+        edatax[datax$extra] = datax$data[datax$extra]
     }
     if(length(datay$test) > 0) {
-        edatay = do.call(rbind, lapply(datay$test, function(x) {
+        edatay = rbind.fill(lapply(datay$test, function(x) {
             datay$data[x,idCols,drop=F]
         }))
     } else {
-        if(!is.null(datay$extra)) {
-            sel = c(idCols, datay$extra)
-        } else {
-            sel = idCols
-        }
-        edatay = datay$data[sel]
+        edatay = datay$data[idCols]
+    }
+    if(!is.null(datay$extra)) {
+        edatay[datay$extra] = datay$data[datay$extra]
     }
 
     scoresx = cbind(edatax, data.frame(scorex=metric(datax, modelx, addCosts=addCostsx, ...)))
